@@ -23,4 +23,12 @@ async def log_response(method_name, response_data, *args, **kwargs):
         "response_data": kwargs.get("response_data", response_data)
     }
     return await asyncPostRequest(getCallUrl(), kwargs, endpoint=endpoint)
-    
+
+async def getAsyncLimitedRequest(endpoint,**kwargs):
+    url = await get_rate_limit_url(method_name)
+    response = await asyncPostRequest(url=url,data=kwargs)
+    await log_response(method_name, response_data)
+    return response
+def callSolcatcherRpc(endpoint,**kwargs)
+    response = asyncio.run(asyncPostRequest(endpoint=endpoint,data=kwargs))
+    return response
